
<template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  >
  </view-grid>
</template>
      <script>
import extend from "@/extension/inbound/receiveOrder.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "receiveOrderId",
      footer: "Foots",
      cnName: "收货单",
      name: "receiveOrder",
      url: "/ReceiveOrder/",
      sortName: "receiveOrderId",
    });

    const searchFormFields = ref({
      orderNo: "",
      upperOrderNo: "",
      orderType: "",
      orderStatus: "",
      createType: "",
      creater: "",
      createDate: "",
    });
    const searchFormOptions = ref([
      [
        { title: "单据编号", field: "orderNo", type: "like" },
        {
          title: "单据类型",
          field: "orderType",
          type: "select",
          dataKey: "inOrderType",
          data: [],
        },
        {
          title: "单据状态",
          field: "orderStatus",
          type: "select",
          dataKey: "inboundState",
          data: [],
        },
      ],
      [
        { title: "创建者", field: "creater", type: "like" },
        { title: "创建时间", field: "createDate", type: "datetime" },
      ],
    ]);

    const editFormFields = ref({
      receiveOrderNo: "",
      receiveOrderType: "",
      suppliersId: "",
      warehouseId: "",
      deliveryCode: "",
    });
    const editFormOptions = ref([
      [
        {
          field: "receiveOrderNo",
          title: "单据编号",
          type: "string",
          readonly: "true",
        },
        {
          title: "单据类型",
          required: true,
          field: "receiveOrderType",
          type: "select",
          dataKey: "receiveOrderTypeEnum",
          data: [],
        },
        {
          title: "供应商",
          field: "suppliersId",
          type: "select",
          dataKey: "suppliers",
          data: [],
          required: true,
        },
        {
          title: "仓库",
          field: "warehouseId",
          type: "select",
          dataKey: "warehouses",
          data: [],
          required: true,
        },
      ],
      [
        {
          title: "送货单号",
          field: "deliveryCode",
          type: "string",
        },
      ],
    ]);
    const columns = ref([
      {
        field: "receiveOrderId",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
      {
        field: "receiveOrderNo",
        title: "收货单号",
        type: "string",
        width: 150,
        align: "left",
        link: true,
      },
      {
        field: "receiveOrderType",
        title: "订单类型",
        type: "string",
        width: 150,
        align: "left",
        bind: { key: "receiveOrderTypeEnum", data: [] },
      },
      {
        field: "receiveOrderStatus",
        title: "订单状态",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "customerId",
        title: "客户代号",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "suppliersId",
        title: "供应商代号",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "warehouseId",
        title: "仓库主键",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "receiveDate",
        title: "收货日期",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "deliveryCode",
        title: "送货单号",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "uploadStatus",
        title: "上传状态",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "remark",
        title: "备注",
        type: "string",
        width: 100,
        align: "left",
      },
    ]);
    const detail = ref({
      cnName: "收货单明细",
      table: "Dt_ReceiveOrderDetail",
      columns: [
        {
          field: "id",
          title: "Id",
          type: "int",
          width: 90,
          hidden: true,
          readonly: true,
          require: true,
          align: "left",
        },
        {
          field: "orderId",
          title: "收货单主键",
          type: "string",
          width: 90,
          align: "left",
          hidden: true,
        },
        {
          field: "rowNo",
          title: "行号",
          type: "string",
          width: 60,
          align: "left",
        },
        {
          field: "purchaseOrderNo",
          title: "采购单号",
          type: "select",
          width: 160,
          align: "left",
          edit: { type: "" },
          required: true,
        },
        {
          field: "materielCode",
          title: "物料编号",
          type: "select",
          width: 150,
          align: "left",
          edit: { type: "" },
          required: true,
        },
        {
          field: "materielName",
          title: "物料名称",
          type: "string",
          width: 150,
          align: "left",
          edit: { type: "" },
        },
        {
          field: "lotNo",
          title: "批次号",
          type: "decimal",
          width: 90,
          align: "left",
          edit: { type: "" },
          required: true,
        },
        {
          field: "receivedQty",
          title: "收货数量",
          type: "decimal",
          width: 90,
          align: "left",
          edit: { type: "number" },
          required: true,
        },
        {
          field: "ifInspection",
          title: "是否检验",
          type: "int",
          width: 90,
          align: "left",
        },
        {
          field: "priceInTax",
          title: "含税价格",
          type: "string",
          width: 90,
          align: "left",
        },
        {
          field: "taxRate",
          title: "税率",
          type: "string",
          width: 90,
          align: "left",
        },
        {
          field: "currCode",
          title: "币别编码",
          type: "string",
          width: 90,
          align: "left",
        },
        {
          field: "creater",
          title: "创建人",
          type: "string",
          width: 90,
          align: "left",
        },
        {
          field: "createDate",
          title: "创建时间",
          type: "datetime",
          width: 160,
          align: "left",
        },
        {
          field: "modifier",
          title: "修改人",
          type: "string",
          width: 100,
          align: "left",
        },
        {
          field: "modifyDate",
          title: "修改时间",
          type: "datetime",
          width: 160,
          align: "left",
        },
        {
          field: "remark",
          title: "备注",
          type: "string",
          width: 100,
          align: "left",
        },
      ],
      sortName: "id",
      key: "id",
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>
      